==> grantlee_0.5.1.orig.tar.gz: grantlee-0.5.1/templates/tests/test_fr_FR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>GR_FILENAME</name>
    <message>
        <location filename="test_input.cpp" line="2"/>
        <source>Birthday</source>
        <translation>Anniversaire</translation>
    </message>
    <message numerus="yes">
        <location filename="test_input.cpp" line="3"/>
        <source>%n People</source>
        <translation>
            <numerusform>%n Personne</numerusform>
            <numerusform>%n Personnes</numerusform>
        </translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="4"/>
        <source>Name</source>
        <comment>Name of a Person</comment>
        <translation>Nom d&apos;une personne</translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="5"/>
        <source>Name</source>
        <comment>Name of a Book</comment>
        <translation>Nom d&apos;un livre</translation>
    </message>
    <message numerus="yes">
        <location filename="test_input.cpp" line="6"/>
        <source>%n People</source>
        <comment>%n people are logged in</comment>
        <translation>
            <numerusform>%n Personne connecté</numerusform>
            <numerusform>%n Personnes connecté</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="test_input.cpp" line="7"/>
        <source>%n file(s) copied to %1</source>
        <translation>
            <numerusform>%n fichier copié dans %1</numerusform>
            <numerusform>%n fichiers copiés dans %1</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="test_input.cpp" line="8"/>
        <source>%n to %1</source>
        <comment>Files are being copied</comment>
        <translation>
            <numerusform>%n fichier est copié sur %1</numerusform>
            <numerusform>%n fichiers sont copiés à %1</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="test_input.cpp" line="9"/>
        <source>%n to %1</source>
        <comment>Files have already been copied</comment>
        <translation>
            <numerusform>%n fichier a été copié à %1</numerusform>
            <numerusform>%n fichiers ont été copiés sur %1</numerusform>
        </translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="10"/>
        <source>from %1 to %2</source>
        <comment>Files are being copied from %1 to %2</comment>
        <translation>à partir de %1 %2</translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="11"/>
        <source>%1 messages at %2, fraction of total: %3. Rating : %4</source>
        <translation>%1 messages au %2, la fraction du total: %3. Note: %4</translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="12"/>
        <source>Today</source>
        <translation>Aujourd&apos;hui</translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="13"/>
        <source>Today is %1</source>
        <translation>Aujourd&apos;hui est %1</translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="14"/>
        <source>Today &amp;amp; tomorrow</source>
        <translation>Aujourd&apos;hui &amp;amp; demain</translation>
    </message>
    <message numerus="yes">
        <location filename="test_input.cpp" line="15"/>
        <source>%n people today</source>
        <translation>
            <numerusform>%n personne aujourd&apos;hui</numerusform>
            <numerusform>%n personnes aujourd&apos;hui</numerusform>
        </translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="16"/>
        <source>Today is</source>
        <comment>The current day is</comment>
        <translation>Aujourd&apos;hui est</translation>
    </message>
    <message numerus="yes">
        <location filename="test_input.cpp" line="17"/>
        <source>%n people visited today</source>
        <oldsource>%n people visted today</oldsource>
        <comment>The number of people who have visited today</comment>
        <translation>
            <numerusform>%n personne a visité aujourd&apos;hui</numerusform>
            <numerusform>%n personnes a visité aujourd&apos;hui</numerusform>
        </translation>
    </message>
</context>
</TS>

==> grantlee5_5.2.0.orig.tar.gz: grantlee-5.2.0/templates/tests/test_fr_FR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>GR_FILENAME</name>
    <message>
        <location filename="test_input.cpp" line="2"/>
        <source>Birthday</source>
        <translation>Anniversaire</translation>
    </message>
    <message numerus="yes">
        <location filename="test_input.cpp" line="3"/>
        <source>%n People</source>
        <translation>
            <numerusform>%n Personne</numerusform>
            <numerusform>%n Personnes</numerusform>
        </translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="4"/>
        <source>Name</source>
        <comment>Name of a Person</comment>
        <translation>Nom d&apos;une personne</translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="5"/>
        <source>Name</source>
        <comment>Name of a Book</comment>
        <translation>Nom d&apos;un livre</translation>
    </message>
    <message numerus="yes">
        <location filename="test_input.cpp" line="6"/>
        <source>%n People</source>
        <comment>%n people are logged in</comment>
        <translation>
            <numerusform>%n Personne connecté</numerusform>
            <numerusform>%n Personnes connecté</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="test_input.cpp" line="7"/>
        <source>%n file(s) copied to %1</source>
        <translation>
            <numerusform>%n fichier copié dans %1</numerusform>
            <numerusform>%n fichiers copiés dans %1</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="test_input.cpp" line="8"/>
        <source>%n to %1</source>
        <comment>Files are being copied</comment>
        <translation>
            <numerusform>%n fichier est copié sur %1</numerusform>
            <numerusform>%n fichiers sont copiés à %1</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="test_input.cpp" line="9"/>
        <source>%n to %1</source>
        <comment>Files have already been copied</comment>
        <translation>
            <numerusform>%n fichier a été copié à %1</numerusform>
            <numerusform>%n fichiers ont été copiés sur %1</numerusform>
        </translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="10"/>
        <source>from %1 to %2</source>
        <comment>Files are being copied from %1 to %2</comment>
        <translation>à partir de %1 %2</translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="11"/>
        <source>%1 messages at %2, fraction of total: %3. Rating : %4</source>
        <translation>%1 messages au %2, la fraction du total: %3. Note: %4</translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="12"/>
        <source>Today</source>
        <translation>Aujourd&apos;hui</translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="13"/>
        <source>Today is %1</source>
        <translation>Aujourd&apos;hui est %1</translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="14"/>
        <source>Today &amp;amp; tomorrow</source>
        <translation>Aujourd&apos;hui &amp;amp; demain</translation>
    </message>
    <message numerus="yes">
        <location filename="test_input.cpp" line="15"/>
        <source>%n people today</source>
        <translation>
            <numerusform>%n personne aujourd&apos;hui</numerusform>
            <numerusform>%n personnes aujourd&apos;hui</numerusform>
        </translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="16"/>
        <source>Today is</source>
        <comment>The current day is</comment>
        <translation>Aujourd&apos;hui est</translation>
    </message>
    <message numerus="yes">
        <location filename="test_input.cpp" line="17"/>
        <source>%n people visited today</source>
        <oldsource>%n people visted today</oldsource>
        <comment>The number of people who have visited today</comment>
        <translation>
            <numerusform>%n personne a visité aujourd&apos;hui</numerusform>
            <numerusform>%n personnes a visité aujourd&apos;hui</numerusform>
        </translation>
    </message>
    <message>
        <location filename="test_input.cpp" line="18"/>
        <source>Snowman: ☃</source>
        <translation>bonhomme de neige: ☃</translation>
    </message>
</context>
</TS>
